@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# flake8: noqa
 
 """
 A terminal environment tools.
@@ -9,10 +10,10 @@ from __future__ import absolute_import
 from .color import *
 from .prompt import *
 from .log import Logger
-from .command import Command
+from .command import Command, Option
 
 log = Logger()
 
 __homepage__ = 'https://github.com/lepture/terminal'
 __author__ = 'Hsiaoming Yang <me@lepture.com>'
-__version__ = '0.1.0'
+__version__ = '0.2.0'
