@@ -8,14 +8,14 @@ import os
 import sys
 
 # Python 3
-if sys.version_info[0] == 3:
+if sys.version_info[0] == 3:  # pragma: no cover
     string_type = str
     unicode = str
 else:
     string_type = basestring
 
 
-def is_color_supported():
+def is_color_supported():  # pragma: no cover
     "Find out if your terminal environment supports color."
     # shinx.util.console
     if not hasattr(sys.stdout, 'isatty'):
@@ -39,7 +39,7 @@ def is_color_supported():
     return term in ('xterm', 'linux') or 'color' in term
 
 
-def is_256color_supported():
+def is_256color_supported():  # pragma: no cover
     "Find out if your terminal environment supports 256 color."
     if not is_color_supported():
         return False
@@ -155,11 +155,11 @@ class Color(object):
             self.styles.append(code + 1)
             return self
         try:
-            return super(Color, self).__getattr__(key)
+            return object.__getattribute__(self, key)
         except AttributeError:
             raise AttributeError("Color has no attribute '%s'" % key)
 
-    def __str__(self):
+    def __str__(self):  # pragma: no cover
         text = ''.join(unicode(item) for item in self.items)
 
         if unicode != str:
@@ -213,12 +213,13 @@ class Color(object):
         return Color(s, self)
 
 
-def colorize(text, color):
+def colorize(text, color, background=False):
     """
     Colorize text with hex code.
 
     :param text: the text you want to paint
     :param color: a hex color or rgb color
+    :param background: decide to colorize background
 
     ::
 
@@ -234,7 +235,10 @@ def colorize(text, color):
         return c
 
     c = Color(text)
-    c.fgcolor = _color2ansi(color)
+    if background:
+        c.bgcolor = _color2ansi(color)
+    else:
+        c.fgcolor = _color2ansi(color)
     return c
 
 
