@@ -5,6 +5,126 @@ import sys
 import inspect
 
 
+class Option(object):
+    """
+    The Option object for Command.
+
+    :param name: the name of the option, usually like ``-v, --verbose``
+    :param description: the description of this option
+    :param action: a function to be invoke when this option is found
+    :param resolve: a function to transform the option data
+    """
+
+    def __init__(self, name, description=None, action=None, resolve=None):
+        self.name = name
+        self.description = description
+        self.action = action
+        self.resolve = resolve
+
+        self.parse(name, description)
+
+    def parse(self, name, description):
+        """
+        Parse option name.
+
+        :param name: option's name
+        :param description: option's description
+
+        Parsing acceptable names:
+
+            * -f: shortname
+            * --force: longname
+            * -f, --force: shortname and longname
+            * -o <output>: shortname and a required value
+            * -o, --output [output]: shortname, longname and optional value
+
+        Parsing default value from description:
+
+            * source directory, default: src
+            * source directory, default: [src]
+            * source directory, default: <src>
+        """
+
+        name = name.strip()
+
+        if '<' in name:
+            self.required = True
+            self.boolean = False
+            name = name[:name.index('<')].strip()
+        elif '[' in name:
+            self.required = False
+            self.boolean = False
+            name = name[:name.index('[')].strip()
+        else:
+            self.required = False
+            self.boolean = True
+
+        regex = re.compile(r'(-\w)?(?:\,\s*)?(--[\w\-]+)?')
+
+        m = regex.findall(name)
+        if not m:
+            raise ValueError('Invalid Option: %s', name)
+
+        shortname, longname = m[0]
+
+        if not shortname and not longname:
+            raise ValueError('Invalid Option: %s', name)
+
+        self.shortname = shortname
+        self.longname = longname
+
+        # parse store key
+        if longname and longname.startswith('--no-'):
+            self.key = longname[5:]
+        elif longname:
+            self.key = longname[2:]
+        else:
+            self.key = shortname
+
+        if self.boolean:
+            # boolean don't need to parse from description
+            if longname and longname.startswith('--no-'):
+                self.default = True
+            else:
+                self.default = False
+            return self
+
+        if not description:
+            self.default = None
+            return self
+
+        # parse default value from description
+        regex = re.compile(r'\sdefault:(.*)$')
+        m = regex.findall(description)
+        if not m:
+            self.default = None
+            return self
+
+        # if it has a default value, it is not required
+        self.required = False
+
+        value = m[0].strip()
+        if value.startswith('<') and value.endswith('>'):
+            value = value[1:-1]
+        elif value.startswith('[') and value.endswith(']'):
+            value = value[1:-1]
+
+        self.default = value.strip()
+        return self
+
+    def to_python(self, value=None):
+        """
+        Transform the option value to python data.
+        """
+
+        if value is None:
+            return self.default
+
+        if self.resolve:
+            return self.resolve(value)
+        return value
+
+
 class Command(object):
     """
     The command interface.
@@ -24,8 +144,16 @@ class Command(object):
     more options::
 
         command.option('-v, --verbose', 'show more logs')
+
+        # required option in < and >
         command.option('-o, --output <output>', 'the output file')
 
+        # optional option in [ and ]
+        command.option('-o, --output [output]', 'the output file')
+
+        # set a default value in description
+        command.option('-o, --source [dir]', 'the output file, default: src')
+
     Usually you will need a subcommand feature, add a subcommand like
     this::
 
@@ -39,13 +167,13 @@ class Command(object):
     with the decorator feature::
 
         @command.action
-        def build(source='.'):
+        def build(output='_build'):
             '''
             generate the documentation.
 
-            :param source: the source directory
+            :param output: the output directory
             '''
-            pass
+            do_something(output)
 
     After defining the command, we can parse the command line argv::
 
@@ -56,29 +184,35 @@ class Command(object):
         assert command.verbose is True
     """
 
-    def __init__(self, name, description=None, version=None, usage=None):
+    def __init__(self, name, description=None, version=None, usage=None,
+                 title=None):
         self._name = name
         self._description = description
         self._version = version
         self._usage = usage
+        self._title = title
 
+        self._parent = None
         self._command_func = None
         self._option_list = []
         self._command_list = []
 
         self._results = {}
-        self._rests = []
+        self._args_results = []
 
-        self.add_default_options()
+        self._add_default_options()
 
     def __getitem__(self, key):
-        return self._results.get(key)
+        return self.get(key)
 
     def __getattr__(self, key):
         try:
-            return super(Command, self).__getattr__(key)
+            return object.__getattribute__(self, key)
         except AttributeError:
-            return self._results.get(key)
+            try:
+                return self.get(key)
+            except ValueError:
+                raise AttributeError('No such attribute: %s' % key)
 
     def __call__(self, func):
         return self.action(func)
@@ -89,7 +223,7 @@ class Command(object):
         argv that are not for options.
         """
 
-        return self._rests
+        return self._args_results
 
     def get(self, key):
         """
@@ -104,9 +238,19 @@ class Command(object):
             # we can also get ``verbose``: command.verbose
         """
 
-        return self._results.get(key)
+        value = self._results.get(key)
+        if value is not None:
+            return value
 
-    def option(self, name, description=None, action=None):
+        # get from option default value
+        option = list(filter(lambda o: o.key == key, self._option_list))
+        if not option:
+            raise ValueError('No such option: %s' % key)
+
+        option = option[0]
+        return option.default
+
+    def option(self, name, description=None, action=None, resolve=None):
         """
         Add or get option.
 
@@ -119,34 +263,45 @@ class Command(object):
         :param name: arguments of the option
         :param description: description of the option
         :param action: a function to be invoked
+        :param resolve: a function to resolve the data
 
         """
-        self._option_list.append((name, description, action))
+
+        if isinstance(name, Option):
+            option = name
+        else:
+            name = name.strip()
+            option = Option(
+                name=name, description=description,
+                action=action, resolve=resolve,
+            )
+
+        self._option_list.append(option)
         return self
 
-    def add_default_options(self):
+    def _add_default_options(self):
+        def print_help():
+            self.print_help()
+            return sys.exit(0)
+
         self.option(
             '-h, --help',
             'output the help menu',
-            self.print_help
+            print_help
         )
+
         if self._version:
+            def print_version():
+                self.print_version()
+                return sys.exit(0)
+
             self.option(
                 '-V, --version',
                 'output the version number',
-                self.print_version
+                print_version
             )
         return self
 
-    def add_log_options(self, verbose_func=None, quiet_func=None):
-        """
-        A helper for setting up log options
-        """
-
-        self.option('-v, --verbose', 'show more logs', verbose_func)
-        self.option('-q, --quiet', 'show less logs', quiet_func)
-        return self
-
     def parse_options(self, arg):
         """
         Parse options with the argv
@@ -161,46 +316,50 @@ class Command(object):
         if '=' in arg:
             arg, value = arg.split('=')
 
-        regex = re.compile(r'(-\w)?(?:\,\s*)?(--[\w\-]+)?(\s+<.*>)?')
         for option in self._option_list:
-            name = option[0].strip()
-            m = regex.findall(name)
-            if not m:
-                raise RuntimeError('Invalid Option: %s', name)
 
-            shortname, longname, tag = m[0]
-
-            if arg not in (shortname, longname):
+            if arg not in (option.shortname, option.longname):
                 continue
 
-            action = option[2]
+            action = option.action
             if action:
                 action()
 
-            if not tag and not longname:
-                self._results[shortname] = True
+            if option.key == option.shortname:
+                self._results[option.key] = True
                 return True
 
-            if not tag and longname.startswith('--no-'):
-                self._results[longname[5:]] = False
+            if option.boolean and option.default:
+                self._results[option.key] = False
                 return True
 
-            if not tag:
-                self._results[longname[2:]] = True
+            if option.boolean:
+                self._results[option.key] = True
                 return True
 
             # has tag, it should has value
             if not value:
-                if self._args:
-                    value = self._args[0]
-                    self._args = self._args[1:]
+                if self._argv:
+                    value = self._argv[0]
+                    self._argv = self._argv[1:]
 
-            tag = tag.strip()
-            self._results[tag[1:-1]] = value
+            if not value:
+                raise RuntimeError('Missing value for: %s', option.name)
+
+            self._results[option.key] = option.to_python(value)
             return True
 
         return False
 
+    def validate_options(self):
+        """
+        Validate options
+        """
+        for option in self._option_list:
+            # validate options
+            if option.required and option.key not in self._results:
+                raise RuntimeError('Option %s is required.' % option.name)
+
     def action(self, command):
         """
         Add a subcommand.
@@ -214,15 +373,15 @@ class Command(object):
         If you prefer a decorator::
 
             @command.action
-            def foo(port=5000):
+            def server(port=5000):
                 '''
                 docstring as the description
 
                 :param port: description of port
                 '''
-                # server(port)
+                start_server(port)
 
-        It will auto generate a subcommand from the ``foo`` function.
+        It will auto generate a subcommand from the ``server`` method.
         """
 
         if isinstance(command, Command):
@@ -264,12 +423,18 @@ class Command(object):
             desc = find_description(arg)
             if arg in kwargs:
                 value = kwargs[arg]
+
                 if value is True:
-                    cmd.option('--no-%s' % arg, desc)
+                    option = Option('--no-%s' % arg, desc)
                 elif value is False:
-                    cmd.option('-%s, --%s' % (arg[0], arg), desc)
+                    option = Option('-%s, --%s' % (arg[0], arg), desc)
                 else:
-                    cmd.option('-%s, --%s <%s>' % (arg[0], arg, arg), desc)
+                    option = Option(
+                        '-%s, --%s [%s]' % (arg[0], arg, arg), desc
+                    )
+                    option.default = value
+
+                cmd.option(option)
             else:
                 cmd.option('-%s, --%s <%s>' % (arg[0], arg, arg), desc)
 
@@ -289,28 +454,35 @@ class Command(object):
         elif isinstance(argv, str):
             argv = argv.split()
 
-        self._args = argv[1:]
-        if not self._args:
+        self._argv = argv[1:]
+        if not self._argv:
             if self._command_func:
                 self._command_func(**self._results)
             return self
 
-        cmd = self._args[0]
+        cmd = self._argv[0]
 
         if not cmd.startswith('-'):
             # parse subcommands
             for command in self._command_list:
                 if isinstance(command, Command) and command._name == cmd:
-                    return command.parse(self._args)
+                    command._parent = self
+                    return command.parse(self._argv)
 
                 if inspect.isfunction(command) and command.__name__ == cmd:
                     return command()
 
-        while self._args:
-            arg = self._args[0]
-            self._args = self._args[1:]
+        while self._argv:
+            arg = self._argv[0]
+            self._argv = self._argv[1:]
             if not self.parse_options(arg):
-                self._rests.append(arg)
+                self._args_results.append(arg)
+
+        # validate
+        self.validate_options()
+
+        if self._parent and isinstance(self._parent, Command):
+            self._parent._args_results = self._args_results
 
         if self._command_func:
             self._command_func(**self._results)
@@ -321,8 +493,15 @@ class Command(object):
         Print the program version.
         """
 
-        print('  %s %s' % (self._name, self._version or ''))
-        return sys.exit(0)
+        if not self._version:
+            return self
+
+        if not self._title:
+            print('  %s %s' % (self._name, self._version))
+            return self
+
+        print('  %s (%s %s)' % (self._title, self._name, self._version))
+        return self
 
     def print_title(self, title):
         """
@@ -350,27 +529,31 @@ class Command(object):
         Print the help menu.
         """
 
-        print('\n  %s %s' % (self._name, self._version or ''))
+        print('\n  %s %s' % (self._title or self._name, self._version or ''))
 
         if self._usage:
             print('\n  %s' % self._usage)
         else:
+            cmd = self._name
+            if hasattr(self, '_parent') and isinstance(self._parent, Command):
+                cmd = '%s %s' % (self._parent._name, cmd)
+
             if self._command_list:
-                usage = 'Usage: %s <command> [option]' % self._name
+                usage = 'Usage: %s <command> [option]' % cmd
             else:
-                usage = 'Usage: %s [option]' % self._name
+                usage = 'Usage: %s [option]' % cmd
             print('\n  %s' % usage)
 
-        arglen = max(len(name) for name, desc, action in self._option_list)
+        arglen = max(len(o.name) for o in self._option_list)
         arglen += 2
 
         self.print_title('\n  Options:\n')
-        for name, desc, action in self._option_list:
-            print('    %s %s' % (_pad(name, arglen), desc or ''))
+        for o in self._option_list:
+            print('    %s %s' % (_pad(o.name, arglen), o.description or ''))
         print('')
 
         if not self._command_list:
-            return sys.exit(0)
+            return self
 
         self.print_title('\n  Commands:\n')
         for cmd in self._command_list:
@@ -384,7 +567,7 @@ class Command(object):
                 print('    %s %s' % (_pad(name, arglen), desc))
 
         print('')
-        return sys.exit(0)
+        return self
 
 
 def _pad(msg, length):
