@@ -3,7 +3,6 @@
 from __future__ import absolute_import
 import sys
 import copy
-from . import color
 
 
 class Logger(object):
@@ -29,6 +28,10 @@ class Logger(object):
         self._is_verbose = False
         self._enable_verbose = False
         self._enable_quiet = False
+
+        self.warn_count = 0
+        self.error_count = 0
+
         self.config(**kwargs)
 
     def config(self, **kwargs):
@@ -70,20 +73,9 @@ class Logger(object):
         """
 
         msg = ' '.join(args)
-        if level == 'start':
-            return color.magenta('=> ') + msg
-        if level == 'end':
-            return color.magenta('* ') + msg
-        m = {
-            'debug': 'gray',
-            'info': 'green',
-            'warn': 'yellow',
-            'error': 'red'
-        }
-        if level in m:
-            fn = getattr(color, m[level])
-            return '%s: %s' % (fn(level), msg)
-        return msg
+        if level not in ('start', 'end', 'debug', 'info', 'warn', 'error'):
+            return msg
+        return '%s: %s' % (level, msg)
 
     def writeln(self, level='info', *args):
         if not self._enable_verbose and self._is_verbose:
@@ -118,6 +110,10 @@ class Logger(object):
         Start a nested log.
         """
 
+        if self._is_verbose:
+            # verbose log has no start method
+            return self
+
         self.writeln('start', *args)
         self._indent += 1
         return self
@@ -127,10 +123,16 @@ class Logger(object):
         End a nested log.
         """
 
-        self._indent -= 1
-        if not args:
+        if self._is_verbose:
+            # verbose log has no end method
             return self
-        return self.writeln('end', *args)
+
+        if not args:
+            self._indent -= 1
+            return self
+        self.writeln('end', *args)
+        self._indent -= 1
+        return self
 
     def debug(self, *args):
         """
@@ -155,6 +157,7 @@ class Logger(object):
         The warn level log.
         """
 
+        self.warn_count += 1
         return self.writeln('warn', *args)
 
     def error(self, *args):
@@ -162,4 +165,5 @@ class Logger(object):
         The error level log.
         """
 
+        self.error_count += 1
         return self.writeln('error', *args)
